This is the package for widget display animation. This package is for single or multiple widgets list.

Features

  • Single Widget presentation animation
  • List of Widget presentation animation

Getting started

widget_animation: ^0.0.1

Usage

SingleWidgetAnimation( animationDuration: const Duration(seconds: 2), delayStart: const Duration(seconds: 6), child: Text( 'Slow Motion', key: const Key('Slow motion'), style: style, ), ),

SingleWidgetAnimation(
  animationDuration: const Duration(seconds: 2),
  delayStart: const Duration(seconds: 6),
  child: child
);

Additional information

This package is for the animation to display text, images or other widgets. This package is usable for single widget as well as list of widgets.