SingleWidgetAnimation class

Inheritance

Constructors

SingleWidgetAnimation({Key? key, required Widget child, double offset = 0.2, Curve curve = Curves.easeIn, Direction direction = Direction.vertical, Duration delayStart = const Duration(seconds: 0), Duration animationDuration = const Duration(milliseconds: 800), double fadeBegin = -1.0, bool enableSlideAnimation = true, Animation<double>? fadeAnimation})
const

Properties

animationDuration Duration
animation duration
final
child Widget
widget to be animated
final
curve Curve
animation curve type
final
delayStart Duration
widget to start in delay
final
direction Direction
direction for animation
final
enableSlideAnimation bool
slide animation enable disable
final
fadeAnimation Animation<double>?
final
fadeBegin double
fade begin value
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset double
animation offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SingleWidgetAnimation>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited